@@ -80,6 +80,9 @@ def tenant_decorator(func):
         token = req_args.pop('token', None)
         if request.method == 'GET':
             data = req_args
+            ignore_creator = data.pop('ignore_creator', "False").lower() == 'true'
+            if ignore_creator:
+                return func(obj_view, request, *args, **kwargs)
         else:
             data = request.data
 
@@ -101,12 +104,10 @@ def tenant_decorator(func):
                     data['creator'] = tenant.name
                 kwargs["data"] = data
             if request.method == 'GET':
-                ignore_creator = data.pop('ignore_creator', "False").lower() == 'true'
-                if not ignore_creator:
-                    if "extend_conditions" in kwargs.keys():
-                        kwargs["extend_conditions"]['creator'] = data
-                    else:
-                        kwargs["extend_conditions"] = {"creator": tenant.name}
+                if "extend_conditions" in kwargs.keys():
+                    kwargs["extend_conditions"]['creator'] = tenant.name
+                else:
+                    kwargs["extend_conditions"] = {"creator": tenant.name}
             return func(obj_view, request, *args, **kwargs)
         else:
             results = Results()
