@@ -130,19 +130,19 @@ class RelatedView(BaseView):
 
     @related_vaild_legal_decorator
     def get(
-            self,
-            request,
-            obj,
-            obj_serializer,
-            data=None,
-            need_results=False,
-            need_queryset=False,
-            keys=None,
-            related_obj: list = None,
-            m_to_m_obj: list = None,
-            related_mapping: dict = None,
-            m_to_m_mapping: dict = None,
-            **kwargs,
+        self,
+        request,
+        obj,
+        obj_serializer,
+        extend_conditions: dict = None,
+        need_results=False,
+        need_queryset=False,
+        keys=None,
+        related_obj: list = None,
+        m_to_m_obj: list = None,
+        related_mapping: dict = None,
+        m_to_m_mapping: dict = None,
+        **kwargs,
     ):
         """
         扩展返回字段（关联表）
@@ -155,7 +155,8 @@ class RelatedView(BaseView):
         :param mapping: 需要扩展字段对应的映射
         :return:
         """
-        results, queryset, current_page_queryset = self.find(obj, request.GET.dict(), obj_serializer)
+        data = self.get_req_args(request, extend_conditions)
+        results, queryset, current_page_queryset = self.find(obj, data, obj_serializer)
 
         try:
             if not related_obj:
@@ -174,17 +175,17 @@ class RelatedView(BaseView):
         return RESTResponse(results)
 
     def post(
-            self,
-            request,
-            obj,
-            obj_serializer,
-            data=None,
-            need_results=False,
-            related_obj: list = None,
-            m_to_m_obj: list = None,
-            related_mapping=None,
-            m_to_m_mapping=None,
-            **kwargs,
+        self,
+        request,
+        obj,
+        obj_serializer,
+        data=None,
+        need_results=False,
+        related_obj: list = None,
+        m_to_m_obj: list = None,
+        related_mapping=None,
+        m_to_m_mapping=None,
+        **kwargs,
     ):
         results = Results()
         if not data:
@@ -224,21 +225,21 @@ class RelatedView(BaseView):
             page_type_results.group = list(extend_queryset)
 
     def put(
-            self,
-            request,
-            obj,
-            obj_serializer,
-            *,
-            data=None,
-            pk="id",
-            extend_conditions: dict = None,
-            need_results=False,
-            need_queryset=False,
-            related_obj: list = None,
-            m_to_m_obj: list = None,
-            related_mapping=None,
-            m_to_m_mapping=None,
-            **kwargs,
+        self,
+        request,
+        obj,
+        obj_serializer,
+        *,
+        data=None,
+        pk="id",
+        extend_conditions: dict = None,
+        need_results=False,
+        need_queryset=False,
+        related_obj: list = None,
+        m_to_m_obj: list = None,
+        related_mapping=None,
+        m_to_m_mapping=None,
+        **kwargs,
     ):
         results = Results()
         if not data:
